@@ -112,10 +112,3 @@ class Squarespace(object):
 
 
 
-def main():
-    #donothing
-    pass
-
-if __name__ == '__main__':
-    # do nothing
-    main()
